@@ -1,7 +1,7 @@
 from . import __shell__
 
 def which(executable):
-    return __shell__.run('which {}'.format(executable), raw=True)[:-1]
+    return __shell__.run('which {}'.format(executable), raw=True).strip()
 
 
 def mkdir(dir_or_dirs):
